(function ($)
{
	$.Redactor.opts.langs['ua'] = {
    "format": "Формат",
    "image": "Зображення",
    "file": "Файл",
    "link": "Посилання",
    "bold": "Жирний",
    "italic": "Курсив",
    "deleted": "Закреслений",
    "underline": "Підкреслений",
    "bold-abbr": "B",
    "italic-abbr": "I",
    "deleted-abbr": "S",
    "underline-abbr": "U",
    "lists": "Списки",
    "link-insert": "Вставити посилання",
    "link-edit": "Редагувати посилання",
    "link-in-new-tab": "Відкрити посилання у новій вкладці",
    "unlink": "Видалити посилання",
    "cancel": "Скасувати",
    "close": "Закрити",
    "insert": "Вставити",
    "save": "Зберегти",
    "delete": "Видалити",
    "text": "Текст",
    "edit": "Редагувати",
    "title": "Заголовок",
    "paragraph": "Параграф",
    "quote": "Цитата",
    "code": "Код",
    "heading1": "Заголовок 1",
    "heading2": "Заголовок 2",
    "heading3": "Заголовок 3",
    "heading4": "Заголовок 4",
    "heading5": "Заголовок 5",
    "heading6": "Заголовок 6",
    "filename": "Назва файлу",
    "optional": "необов'язково",
    "unorderedlist": "Ненумерований список",
    "orderedlist": "Нумерований список",
    "outdent": "Забрати відступ",
    "indent": "Додати відступ",
    "horizontalrule": "Лінія",
    "upload-label": "Перетягніть файл або ",
    "accessibility-help-label": "Редактор форматованого тексту",
    "caption": "Підпис",
    "bulletslist": "Маркери",
    "numberslist": "Нумерація",
    "image-position": "Position",
    "none": "None",
    "left": "Left",
    "right": "Right",
    "center": "Center"
};

})(jQuery);