(function ($)
{
	$.Redactor.opts.langs['de'] = {
    "format": "Format",
    "image": "Bild",
    "file": "Datei",
    "link": "Link",
    "bold": "Fett",
    "italic": "Kursiv",
    "deleted": "Durchgestrichen",
    "underline": "Unterstrichen",
    "bold-abbr": "B",
    "italic-abbr": "I",
    "deleted-abbr": "S",
    "underline-abbr": "U",
    "lists": "Listen",
    "link-insert": "Verknüpfung einsetzen",
    "link-edit": "Verknüpfung bearbeiten",
    "link-in-new-tab": "Verknüpfung in neuer Registerkarte öffnen",
    "unlink": "Verknüpfung aufheben",
    "cancel": "Abbrechen",
    "close": "Schließen",
    "insert": "Einsetzen",
    "save": "Speichern",
    "delete": "löschen",
    "text": "Text",
    "edit": "Bearbeiten",
    "title": "Titel",
    "paragraph": "Normaler Text",
    "quote": "Zitieren",
    "code": "Code",
    "heading1": "Überschrift 1",
    "heading2": "Überschrift 2",
    "heading3": "Überschrift 3",
    "heading4": "Überschrift 4",
    "heading5": "Überschrift 5",
    "heading6": "Überschrift 6",
    "filename": "Name",
    "optional": "Optional",
    "unorderedlist": "Unsortierte Liste",
    "orderedlist": "Sortierte Liste",
    "outdent": "Negativer einzug",
    "indent": "Einzug",
    "horizontalrule": "Linie",
    "upload-label": "Datei hier ablegen oder ",
    "accessibility-help-label": "Rich-Text-Editor",
    "caption": "Caption",
    "bulletslist": "Bullets",
    "numberslist": "Numbers",
    "image-position": "Position",
    "none": "None",
    "left": "Left",
    "right": "Right",
    "center": "Center"
};

})(jQuery);