(function ($)
{
	$.Redactor.opts.langs['pt_br'] = {
    "format": "Formato",
    "image": "Imagem",
    "file": "Arquivo",
    "link": "Link",
    "bold": "Negrito",
    "italic": "Itálico",
    "deleted": "Tachado",
    "underline": "Sublinhado",
    "bold-abbr": "N",
    "italic-abbr": "I",
    "deleted-abbr": "T",
    "underline-abbr": "S",
    "lists": "Listas",
    "link-insert": "Inserir link",
    "link-edit": "Editar link",
    "link-in-new-tab": "Abrir link em nova guia",
    "unlink": "Desvincular",
    "cancel": "Cancelar",
    "close": "Fechar",
    "insert": "Inserir",
    "save": "Salvar",
    "delete": "Excluir",
    "text": "Texto",
    "edit": "Editar",
    "title": "Título",
    "paragraph": "Texto normal",
    "quote": "Citação",
    "code": "Código",
    "header1": "Cabeçalho 1",
    "header2": "Cabeçalho 2",
    "header3": "Cabeçalho 3",
    "header4": "Cabeçalho 4",
    "header5": "Cabeçalho 5",
    "header6": "Cabeçalho 6",
    "filename": "Nome",
    "optional": "Opcional",
    "unorderedlist": "Lista não ordenada",
    "orderedlist": "Lista ordenada",
    "outdent": "Diminuir recuo",
    "indent": "Recuar",
    "horizontalrule": "Linha",
    "upload-label": "Solte o arquivo aqui ou ",
    "accessibility-help-label": "Editor de Rich Text",
    "caption": "Caption",
    "bulletslist": "Bullets",
    "numberslist": "Numbers",
    "image-position": "Position",
    "none": "None",
    "left": "Left",
    "right": "Right",
    "center": "Center"
};

})(jQuery);