(function ($)
{
	$.Redactor.opts.langs['sv'] = {
    "format": "Format",
    "image": "Bild",
    "file": "Fil",
    "link": "Länk",
    "bold": "Fet",
    "italic": "Kursiv",
    "deleted": "Överstruken",
    "underline": "Understruken",
    "bold-abbr": "B",
    "italic-abbr": "I",
    "deleted-abbr": "S",
    "underline-abbr": "U",
    "lists": "Lista",
    "link-insert": "Infoga länk",
    "link-edit": "Redigera länk",
    "link-in-new-tab": "Öppna länk i nytt fönster",
    "unlink": "Radera länk",
    "cancel": "Avbryt",
    "close": "Stäng",
    "insert": "Infoga",
    "save": "Spara",
    "delete": "Radera",
    "text": "Text",
    "edit": "Redigera",
    "title": "Titel",
    "paragraph": "Normal text",
    "quote": "Citat",
    "code": "Kod",
    "heading1": "Titel 1",
    "heading2": "Titel 2",
    "heading3": "Titel 3",
    "heading4": "Titel 4",
    "heading5": "Titel 5",
    "heading6": "Titel 6",
    "filename": "Namn",
    "optional": "valfritt",
    "unorderedlist": "Osorterad lista",
    "orderedlist": "Sorterad lista",
    "outdent": "Minska utdrag",
    "indent": "Öka utdrag",
    "horizontalrule": "Linje",
    "upload-label": "Släpp filen här eller ",
    "accessibility-help-label": "Textredigerare",
    "caption": "Caption",
    "bulletslist": "Bullets",
    "numberslist": "Numbers",
    "image-position": "Position",
    "none": "None",
    "left": "Left",
    "right": "Right",
    "center": "Center"
};

})(jQuery);