/*
	Redactor II

	http://imperavi.com/redactor/

	Copyright (c) 2009-2017, Imperavi Oy.
	License: http://imperavi.com/redactor/license/
*/
@font-face {
  font-family: 'Redactor';
  src: url("data:application/x-font-ttf;charset=utf-8;base64, ") format("truetype");
  font-weight: normal;
  font-style: normal; }

[class^="re-icon-"], [class*=" re-icon-"] {
  /* use !important to prevent issues with browser extensions that change fonts */
  font-family: 'Redactor' !important;
  speak: none;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale; }

.re-icon-aligncenter:before {
  content: "\e900"; }

.re-icon-alignment:before,
.re-icon-alignleft:before {
  content: "\e901"; }

.re-icon-alignright:before {
  content: "\e902"; }

.re-icon-bold:before {
  content: "\e903"; }

.re-icon-bookmark:before {
  content: "\e904"; }

.re-icon-clips:before {
  content: "\e905"; }

.re-icon-codesnippets:before {
  content: "\e906"; }

.re-icon-deleted:before {
  content: "\e907"; }

.re-icon-expand:before {
  content: "\e908"; }

.re-icon-file:before {
  content: "\e909"; }

.re-icon-fontcolor:before {
  content: "\e90a"; }

.re-icon-fontfamily:before {
  content: "\e90b"; }

.re-icon-fontsize:before {
  content: "\e90c"; }

.re-icon-format:before {
  content: "\e90d"; }

.re-icon-html:before {
  content: "\e90e"; }

.re-icon-imagecenter:before {
  content: "\e90f"; }

.re-icon-imageleft:before {
  content: "\e910"; }

.re-icon-imageright:before {
  content: "\e911"; }

.re-icon-image:before {
  content: "\e912"; }

.re-icon-indent:before {
  content: "\e913"; }

.re-icon-inline:before {
  content: "\e914"; }

.re-icon-italic:before {
  content: "\e915"; }

.re-icon-horizontalrule:before {
  content: "\e916"; }

.re-icon-link:before {
  content: "\e917"; }

.re-icon-ol:before,
.re-icon-ordered:before {
  content: "\e918"; }

.re-icon-outdent:before {
  content: "\e919"; }

.re-icon-properties:before {
  content: "\e91a"; }

.re-icon-readmore:before {
  content: "\e91b"; }

.re-icon-redo:before {
  content: "\e91c"; }

.re-icon-retract:before {
  content: "\e91d"; }

.re-icon-specialcharacters:before {
  content: "\e91e"; }

.re-icon-sub:before {
  content: "\e91f"; }

.re-icon-sup:before {
  content: "\e920"; }

.re-icon-table:before {
  content: "\e921"; }

.re-icon-textdirection:before {
  content: "\e922"; }

.re-icon-toggle:before {
  content: "\e923"; }

.re-icon-underline:before {
  content: "\e924"; }

.re-icon-undo:before {
  content: "\e925"; }

.re-icon-ul:before,
.re-icon-lists:before,
.re-icon-unordered:before {
  content: "\e926"; }

.re-icon-video:before {
  content: "\e927"; }

.redactor-box {
  position: relative;
  overflow: visible; }

.redactor-layer,
.redactor-box {
  background: #fff; }

.redactor-layer,
.redactor-box,
.redactor-box textarea {
  z-index: auto; }

.redactor-link-tooltip {
  z-index: 99; }

.redactor-toolbar {
  z-index: 100; }

.redactor-box-fullscreen {
  z-index: 1051; }

.redactor-air,
.redactor-dropdown {
  z-index: 1052; }

#redactor-modal-overlay,
#redactor-modal-box,
#redactor-modal {
  z-index: 1053; }

.redactor-body-fullscreen .redactor-link-tooltip {
  z-index: 1099; }

.redactor-box-fullscreen {
  position: fixed;
  top: 0;
  left: 0;
  width: 100%; }

.redactor-placeholder:after {
  position: absolute;
  top: 20px;
  left: 20px;
  content: attr(placeholder);
  display: block;
  color: rgba(0, 0, 0, 0.3);
  font-weight: normal !important; }

.redactor-layer {
  position: relative;
  overflow: auto;
  margin: 0;
  padding: 24px 20px;
  padding-top: 20px;
  outline: none;
  white-space: normal;
  border: 1px solid rgba(0, 0, 0, 0.07); }

.redactor-relative {
  position: relative; }

.redactor-in {
  cursor: text; }

.redactor-layer:focus,
.redactor-in:focus {
  outline: none; }

.redactor-scrollbar-measure {
  position: absolute;
  top: -9999px;
  width: 50px;
  height: 50px;
  overflow: scroll; }

.redactor-script-tag {
  display: none; }

.redactor-layer-img-edit img {
  cursor: pointer; }

.redactor-voice-label {
  display: none; }

.redactor-voice-alert {
  position: absolute;
  left: -3000px; }

.redactor-toolbar {
  position: relative;
  padding: 0 !important;
  background: #fff;
  border: none;
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.25); }
  .redactor-toolbar:after {
    content: "";
    display: table;
    clear: both; }

.redactor-toolbar li a {
  color: rgba(0, 0, 0, 0.8); }
  .redactor-toolbar li a:hover {
    outline: none;
    background-color: #3d79f2;
    color: #fff; }
  .redactor-toolbar li a:active, .redactor-toolbar li a.redactor-act {
    outline: none;
    background-color: #eee;
    color: #444; }

.redactor-toolbar li a.redactor-button-disabled {
  opacity: 0.3; }
  .redactor-toolbar li a.redactor-button-disabled:hover {
    color: #333;
    outline: none;
    background-color: transparent !important;
    cursor: default; }

.redactor-toolbar li a.redactor-button-focus {
  color: #fff;
  background: #000; }

.redactor-toolbar.redactor-toolbar-external {
  z-index: 999;
  border: 1px solid rgba(0, 0, 0, 0.1);
  box-shadow: none; }

.redactor-air {
  position: absolute;
  background: rgba(0, 0, 0, 0.9);
  padding: 0;
  max-width: 576px;
  min-width: 200px;
  border-radius: 4px;
  border: none; }

.redactor-air li a {
  color: rgba(255, 255, 255, 0.75); }
  .redactor-air li a:hover {
    outline: none;
    background-color: #1f78d8;
    color: #fff; }
  .redactor-air li a:active, .redactor-air li a.redactor-act {
    outline: none;
    background-color: #333;
    color: rgba(255, 255, 255, 0.5); }

.redactor-air li a.redactor-button-disabled {
  opacity: .3; }
  .redactor-air li a.redactor-button-disabled:hover {
    color: rgba(255, 255, 255, 0.3);
    outline: none;
    background-color: transparent !important;
    cursor: default; }

.redactor-air li a.redactor-button-focus {
  color: #333;
  background: #eee; }

.redactor-air,
.redactor-toolbar {
  font-family: "Trebuchet MS", "Helvetica Neue", Helvetica, Tahoma, sans-serif;
  margin: 0 !important;
  list-style: none !important;
  line-height: 1 !important; }

.redactor-air li,
.redactor-toolbar li {
  vertical-align: top;
  display: inline-block;
  margin: 0 !important;
  padding: 0 !important;
  outline: none;
  list-style: none !important; }

.redactor-air li a,
.redactor-toolbar li a {
  box-sizing: border-box;
  font-size: 14px;
  display: block;
  text-align: center;
  line-height: 48px;
  height: 48px;
  padding: 16px;
  padding-top: 17px;
  padding-bottom: 15px;
  cursor: pointer;
  outline: none;
  border: none;
  line-height: 1;
  text-decoration: none;
  cursor: pointer;
  zoom: 1;
  position: relative; }
  .redactor-air li a.re-button-icon,
  .redactor-toolbar li a.re-button-icon {
    padding: 16px;
    font-size: 16px; }
  .redactor-air li a .re-button-tooltip,
  .redactor-toolbar li a .re-button-tooltip {
    display: none;
    position: absolute;
    white-space: nowrap;
    left: 50%;
    bottom: -18px;
    background: rgba(0, 0, 0, 0.9);
    border-radius: 2px;
    padding: 3px 8px;
    color: rgba(255, 255, 255, 0.8);
    font-size: 12px;
    font-family: Consolas, Menlo, Monaco, "Courier New", monospace; }

.redactor-toolbar li a {
  border-right: 1px solid rgba(0, 0, 0, 0.05); }

.redactor-toolbar li:last-child a {
  border-right: none; }

.redactor-link-tooltip {
  border-radius: 3px;
  font-family: "Trebuchet MS", "Helvetica Neue", Helvetica, Tahoma, sans-serif;
  position: absolute;
  padding: 16px;
  line-height: 1;
  display: inline-block;
  background-color: rgba(0, 0, 0, 0.95);
  color: #555 !important;
  font-size: 14px; }

.redactor-link-tooltip a {
  font-size: 14px;
  color: #ccc;
  margin: 0 8px;
  text-decoration: none; }
  .redactor-link-tooltip a:hover {
    color: #fff; }

.redactor-structure h1, .redactor-structure h2, .redactor-structure h3, .redactor-structure h4, .redactor-structure h5, .redactor-structure h6, .redactor-structure div {
  position: relative; }
  .redactor-structure h1:before, .redactor-structure h2:before, .redactor-structure h3:before, .redactor-structure h4:before, .redactor-structure h5:before, .redactor-structure h6:before, .redactor-structure div:before {
    width: 24px;
    position: absolute;
    font-size: 10px;
    font-weight: normal;
    opacity: .3;
    left: -28px;
    text-align: right; }

.redactor-structure h1:before {
  content: "h1"; }

.redactor-structure h2:before {
  content: "h2"; }

.redactor-structure h3:before {
  content: "h3"; }

.redactor-structure h4:before {
  content: "h4"; }

.redactor-structure h5:before {
  content: "h5"; }

.redactor-structure h6:before {
  content: "h6"; }

.redactor-structure div:before {
  content: "div"; }

#redactor-image-box {
  position: relative;
  max-width: 100%;
  display: inline-block;
  line-height: 0;
  outline: 3px solid #1f78d8;
  box-shadow: 0 0 12px #1f78d8; }

#redactor-image-editter {
  position: absolute;
  z-index: 5;
  top: 50%;
  left: 50%;
  margin-top: -11px;
  margin-left: -18px;
  line-height: 1;
  background-color: rgba(0, 0, 0, 0.9);
  border-radius: 3px;
  color: #fff;
  font-size: 12px;
  padding: 7px 10px;
  cursor: pointer; }

#redactor-image-resizer {
  box-sizing: border-box;
  position: absolute;
  z-index: 2;
  line-height: 1;
  cursor: nw-resize;
  bottom: -5px;
  right: -6px;
  border: 2px solid #000;
  background-color: rgba(255, 255, 255, 0.9);
  width: 10px;
  height: 10px; }

#redactor-droparea {
  position: relative;
  overflow: hidden;
  padding: 64px 24px;
  border: 3px dashed rgba(0, 0, 0, 0.1); }

#redactor-droparea.drag-hover {
  background: rgba(200, 222, 250, 0.75); }

#redactor-droparea.drag-drop {
  background: rgba(250, 248, 200, 0.5); }

#redactor-droparea-placeholder {
  text-align: center;
  font-size: 12px;
  margin-left: 64px;
  color: rgba(0, 0, 0, 0.7); }

.redactor-image-dragover {
  outline: 2px solid #3d79f2; }

#redactor-progress {
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  z-index: 1000000;
  height: 10px; }

#redactor-progress span {
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.2) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.2) 50%, rgba(255, 255, 255, 0.2) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(45deg, rgba(255, 255, 255, 0.2) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.2) 50%, rgba(255, 255, 255, 0.2) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.2) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.2) 50%, rgba(255, 255, 255, 0.2) 75%, transparent 75%, transparent);
  -webkit-animation: progress-bar-stripes 2s linear infinite;
  -o-animation: progress-bar-stripes 2s linear infinite;
  animation: progress-bar-stripes 2s linear infinite;
  display: block;
  width: 100%;
  height: 100%;
  background-color: #3d58a8;
  background-size: 40px 40px; }

@-webkit-keyframes progress-bar-stripes {
  from {
    background-position: 40px 0; }
  to {
    background-position: 0 0; } }

@-o-keyframes progress-bar-stripes {
  from {
    background-position: 40px 0; }
  to {
    background-position: 0 0; } }

@keyframes progress-bar-stripes {
  from {
    background-position: 40px 0; }
  to {
    background-position: 0 0; } }

.redactor-animated {
  -webkit-animation-duration: 1s;
  animation-duration: 1s;
  -webkit-animation-fill-mode: both;
  animation-fill-mode: both; }

@-webkit-keyframes redactorSlideUp {
  to {
    padding-top: 0;
    padding-bottom: 0;
    height: 0; } }

@keyframes redactorSlideUp {
  to {
    padding-top: 0;
    padding-bottom: 0;
    height: 0; } }

.redactor-slideUp {
  overflow: hidden;
  -webkit-animation-name: redactorSlideUp;
  animation-name: redactorSlideUp; }

@-webkit-keyframes redactorSlideDown {
  from {
    height: 0;
    padding-top: 0;
    padding-bottom: 0; } }

@keyframes redactorSlideDown {
  from {
    height: 0;
    padding-top: 0;
    padding-bottom: 0; } }

.redactor-slideDown {
  overflow: hidden;
  -webkit-animation-name: redactorSlideDown;
  animation-name: redactorSlideDown; }

@-webkit-keyframes redactorFadeIn {
  from {
    opacity: 0; }
  to {
    opacity: 1; } }

@keyframes redactorFadeIn {
  from {
    opacity: 0; }
  to {
    opacity: 1; } }

.redactor-fadeIn {
  -webkit-animation-name: redactorFadeIn;
  animation-name: redactorFadeIn; }

@-webkit-keyframes redactorFadeOut {
  from {
    opacity: 1; }
  to {
    opacity: 0; } }

@keyframes redactorFadeOut {
  from {
    opacity: 1; }
  to {
    opacity: 0; } }

.redactor-fadeOut {
  -webkit-animation-name: redactorFadeOut;
  animation-name: redactorFadeOut; }

.redactor-dropdown {
  font-family: "Trebuchet MS", "Helvetica Neue", Helvetica, Tahoma, sans-serif;
  min-width: 220px;
  max-height: 254px;
  color: #000;
  margin: 0;
  padding: 0;
  font-size: 14px;
  background: #fff;
  box-shadow: 0 5px 20px rgba(0, 0, 0, 0.2);
  overflow: auto;
  list-style: none; }

.redactor-dropdown li {
  border-bottom: 1px solid rgba(0, 0, 0, 0.07); }
  .redactor-dropdown li:last-child {
    border-bottom: none; }
  .redactor-dropdown li:hover {
    background-color: #3d79f2; }
    .redactor-dropdown li:hover a {
      color: #fff !important;
      text-decoration: none; }
  .redactor-dropdown li.redactor-dropdown-link-inactive {
    background: none; }
    .redactor-dropdown li.redactor-dropdown-link-inactive a,
    .redactor-dropdown li.redactor-dropdown-link-inactive a:hover {
      background: none;
      cursor: default;
      color: #000 !important;
      opacity: 0.4;
      background: none; }

.redactor-dropdown a {
  display: block;
  padding: 12px 10px;
  color: #000;
  text-decoration: none; }
  .redactor-dropdown a span {
    padding: 2px 4px 1px 4px;
    display: inline-block;
    border-radius: 3px;
    line-height: 1; }
  .redactor-dropdown a:focus {
    outline: none; }
  .redactor-dropdown a.selected {
    background-color: #000;
    color: #fff; }
  .redactor-dropdown a.redactor-dropdown-link-selected {
    color: #fff;
    background: #000; }

.redactor-dropdown-box-inline .redactor-dropdown-marked span {
  background-color: #ffd61e;
  color: #000;
  text-decoration: none; }

.redactor-dropdown-box-inline .redactor-dropdown-code span {
  font-family: Consolas, Menlo, Monaco, "Courier New", monospace;
  background: rgba(0, 0, 0, 0.05); }

.redactor-dropdown-box-inline .redactor-dropdown-sample span {
  font-family: Consolas, Menlo, Monaco, "Courier New", monospace;
  background: #46a9fc;
  color: rgba(255, 255, 255, 0.9); }

.redactor-dropdown-box-inline .redactor-dropdown-variable span {
  font-family: Consolas, Menlo, Monaco, "Courier New", monospace;
  color: rgba(0, 0, 0, 0.5); }

.redactor-dropdown-box-inline .redactor-dropdown-shortcut span {
  font-family: Consolas, Menlo, Monaco, "Courier New", monospace;
  background: #000;
  color: rgba(255, 255, 255, 0.85);
  white-space: nowrap; }

.redactor-dropdown-box-inline .redactor-dropdown-cite span {
  color: rgba(0, 0, 0, 0.5);
  font-style: italic; }

.redactor-dropdown-box-inline .redactor-dropdown-sup span,
.redactor-dropdown-box-inline .redactor-dropdown-sub span {
  font-size: 12px; }

.redactor-dropdown-box-format .redactor-dropdown-blockquote {
  color: rgba(0, 0, 0, 0.4);
  font-style: italic; }

.redactor-dropdown-box-format .redactor-dropdown-pre {
  font-family: monospace, sans-serif; }

.redactor-dropdown-box-format .redactor-dropdown-h1,
.redactor-dropdown-box-format .redactor-dropdown-h2,
.redactor-dropdown-box-format .redactor-dropdown-h3,
.redactor-dropdown-box-format .redactor-dropdown-h4,
.redactor-dropdown-box-format .redactor-dropdown-h5,
.redactor-dropdown-box-format .redactor-dropdown-h6 {
  line-height: 24px;
  font-weight: bold; }

.redactor-dropdown-box-format .redactor-dropdown-h1 {
  font-size: 40px;
  line-height: 32px; }

.redactor-dropdown-box-format .redactor-dropdown-h2 {
  font-size: 32px;
  line-height: 32px; }

.redactor-dropdown-box-format .redactor-dropdown-h3 {
  font-size: 24px; }

.redactor-dropdown-box-format .redactor-dropdown-h4 {
  font-size: 21px; }

.redactor-dropdown-box-format .redactor-dropdown-h5 {
  font-size: 18px; }

.redactor-dropdown-box-format .redactor-dropdown-h6 {
  font-size: 16px; }

#redactor-modal-overlay {
  position: fixed;
  top: 0;
  left: 0;
  margin: auto;
  overflow: auto;
  width: 100%;
  height: 100%;
  background-color: rgba(255, 255, 255, 0.95); }

#redactor-modal-box {
  position: fixed;
  top: 0;
  left: 0;
  bottom: 0;
  right: 0;
  overflow-x: hidden;
  overflow-y: auto; }

#redactor-modal {
  position: relative;
  margin: auto;
  margin-top: 16px;
  padding: 0;
  background: #fff;
  color: #000;
  border-radius: 5px;
  box-shadow: 0 4px 40px rgba(0, 0, 0, 0.15);
  font-family: "Trebuchet MS", "Helvetica Neue", Helvetica, Tahoma, sans-serif;
  font-size: 14px; }
  @media (max-width: 768px) {
    #redactor-modal {
      font-size: 16px !important; } }
  #redactor-modal #redactor-modal-header {
    border-top-right-radius: 5px;
    border-top-left-radius: 5px;
    padding: 20px;
    font-size: 18px;
    font-weight: bold;
    color: #000;
    border-bottom: 1px solid rgba(0, 0, 0, 0.05); }
  #redactor-modal #redactor-modal-close {
    position: absolute;
    top: 10px;
    right: 4px;
    width: 30px;
    height: 40px;
    text-align: center;
    color: rgba(0, 0, 0, 0.3);
    font-size: 30px;
    font-weight: 300;
    cursor: pointer;
    -webkit-appearance: none;
    padding: 0;
    border: 0;
    background: none;
    outline: none; }
    #redactor-modal #redactor-modal-close:hover {
      color: #000; }
  #redactor-modal #redactor-modal-body {
    overflow: auto;
    padding: 40px 48px 24px 48px; }
    #redactor-modal #redactor-modal-body section {
      margin-bottom: 24px; }
    #redactor-modal #redactor-modal-body label {
      font-weight: normal;
      font-size: 15px;
      display: block;
      margin-bottom: 4px;
      color: rgba(0, 0, 0, 0.8); }
      #redactor-modal #redactor-modal-body label .desc {
        color: rgba(0, 0, 0, 0.5); }
      #redactor-modal #redactor-modal-body label.checkbox {
        font-size: inherit; }
    @media (max-width: 768px) {
      #redactor-modal #redactor-modal-body {
        padding: 24px; } }
  #redactor-modal select,
  #redactor-modal input[type="text"],
  #redactor-modal input[type="password"],
  #redactor-modal input[type="email"],
  #redactor-modal input[type="url"],
  #redactor-modal input[type="number"],
  #redactor-modal textarea {
    box-sizing: border-box;
    position: relative;
    z-index: 2;
    margin: 0;
    padding: 8px;
    height: 40px;
    border: 1px solid #ddd;
    border-radius: 3px;
    background-color: white;
    box-shadow: none;
    color: #333;
    width: 100%;
    font-size: 16px;
    font-family: "Trebuchet MS", "Helvetica Neue", Helvetica, Tahoma, sans-serif; }
    #redactor-modal select:focus,
    #redactor-modal input[type="text"]:focus,
    #redactor-modal input[type="password"]:focus,
    #redactor-modal input[type="email"]:focus,
    #redactor-modal input[type="url"]:focus,
    #redactor-modal input[type="number"]:focus,
    #redactor-modal textarea:focus {
      -moz-transition: border 0.3s ease-in;
      transition: border 0.3s ease-in;
      outline: none;
      border-color: #1f78d8; }
  #redactor-modal textarea {
    display: block;
    line-height: 1.4em; }
  #redactor-modal button {
    padding: 0 20px;
    margin: 0;
    margin-bottom: 8px;
    margin-right: 8px;
    height: 40px;
    line-height: 38px;
    outline: none;
    border: 2px solid transparent;
    border-radius: 3px;
    background-color: #eee;
    color: #000;
    text-align: center;
    text-decoration: none;
    font-weight: normal;
    font-size: 15px;
    font-family: "Trebuchet MS", "Helvetica Neue", Helvetica, Tahoma, sans-serif;
    cursor: pointer;
    vertical-align: middle;
    -webkit-appearance: none; }
    #redactor-modal button:hover {
      color: #777;
      background: none;
      background-color: #f5f5f5;
      text-decoration: none; }
    #redactor-modal button.redactor-modal-button-offset {
      margin-left: 24px; }
    #redactor-modal button#redactor-modal-button-delete {
      background: none;
      border-color: #f23d3d;
      color: #f23d3d; }
      #redactor-modal button#redactor-modal-button-delete:hover {
        color: rgba(255, 255, 255, 0.6);
        background-color: #f23d3d; }
    #redactor-modal button#redactor-modal-button-action {
      background: none;
      color: #fff;
      background-color: #1c86f2; }
      #redactor-modal button#redactor-modal-button-action:hover {
        color: rgba(255, 255, 255, 0.6);
        background-color: #4ca0f5; }
  #redactor-modal .redactor-group:after {
    content: "";
    display: table;
    clear: both; }
  #redactor-modal .redactor-modal-tab-side {
    float: left;
    width: 26%;
    margin-right: 6%; }
  #redactor-modal .redactor-modal-tab-area {
    float: left;
    width: 66%; }
  @media (max-width: 768px) {
    #redactor-modal .redactor-modal-tab-side {
      float: none;
      width: auto;
      margin-right: 0;
      margin-bottom: 24px; }
    #redactor-modal .redactor-modal-tab-area {
      float: none;
      width: auto; } }

#redactor-modal-tabber {
  margin-bottom: 40px;
  font-size: 12px; }
  #redactor-modal-tabber a {
    border: 1px solid #ddd;
    line-height: 1;
    padding: 8px 15px;
    margin-right: -1px;
    text-decoration: none;
    color: #000; }
    #redactor-modal-tabber a:hover {
      background-color: #1f78d8;
      border-color: #1f78d8;
      color: #fff; }
    #redactor-modal-tabber a.active {
      cursor: default;
      background-color: rgba(0, 0, 0, 0.05);
      border-color: #ddd;
      color: rgba(0, 0, 0, 0.5); }

#redactor-modal-list {
  margin-left: 0;
  padding-left: 0;
  list-style: none;
  max-height: 250px;
  overflow-x: auto; }
  #redactor-modal-list li {
    border-bottom: 1px solid rgba(0, 0, 0, 0.07); }
    #redactor-modal-list li:last-child {
      border-bottom: none; }
  #redactor-modal-list a {
    padding: 16px 4px;
    color: #000;
    text-decoration: none;
    font-size: 15px;
    display: block;
    position: relative; }
    #redactor-modal-list a:hover {
      background-color: #eee; }

.redactor-styles {
  font-family: "Trebuchet MS", "Helvetica Neue", Helvetica, Tahoma, sans-serif;
  font-size: 16px;
  line-height: 24px;
  color: #333; }
  .redactor-styles[dir="rtl"] {
    direction: rtl;
    unicode-bidi: embed; }
    .redactor-styles[dir="rtl"] ul li,
    .redactor-styles[dir="rtl"] ol li {
      text-align: right; }
    .redactor-styles[dir="rtl"] ul,
    .redactor-styles[dir="rtl"] ol,
    .redactor-styles[dir="rtl"] ul ul,
    .redactor-styles[dir="rtl"] ol ol,
    .redactor-styles[dir="rtl"] ul ol,
    .redactor-styles[dir="rtl"] ol ul {
      margin: 0 24px 0 0; }
  @media (max-width: 768px) {
    .redactor-styles {
      font-size: 16px; } }
  .redactor-styles a {
    color: #256bc9; }
    .redactor-styles a:focus, .redactor-styles a:hover {
      color: #e21e3b; }
  .redactor-styles h1,
  .redactor-styles h2,
  .redactor-styles h3,
  .redactor-styles h4,
  .redactor-styles h5,
  .redactor-styles h6 {
    font-family: "Trebuchet MS", "Helvetica Neue", Helvetica, Tahoma, sans-serif;
    font-weight: bold;
    color: #222;
    text-rendering: optimizeLegibility;
    margin: 0;
    padding: 0;
    margin-bottom: 12px; }
    .redactor-styles h1:empty,
    .redactor-styles h2:empty,
    .redactor-styles h3:empty,
    .redactor-styles h4:empty,
    .redactor-styles h5:empty,
    .redactor-styles h6:empty {
      min-height: 24px; }
  .redactor-styles h1 {
    font-size: 40px;
    line-height: 44px; }
  .redactor-styles h2 {
    font-size: 32px;
    line-height: 36px; }
  .redactor-styles h3 {
    font-size: 24px;
    line-height: 32px; }
  .redactor-styles h4 {
    font-size: 21px;
    line-height: 24px; }
  .redactor-styles h5 {
    font-size: 18px;
    line-height: 24px; }
  .redactor-styles h6 {
    font-size: 16px;
    line-height: 24px; }
  .redactor-styles p,
  .redactor-styles ul,
  .redactor-styles ol,
  .redactor-styles dl,
  .redactor-styles blockquote,
  .redactor-styles hr,
  .redactor-styles pre,
  .redactor-styles table,
  .redactor-styles figure,
  .redactor-styles address {
    padding: 0;
    margin: 0; }
  .redactor-styles p:empty,
  .redactor-styles blockquote:empty {
    min-height: 24px; }
  .redactor-styles p + h2,
  .redactor-styles p + h3,
  .redactor-styles p + h4,
  .redactor-styles p + h5,
  .redactor-styles p + h6,
  .redactor-styles ul + h2,
  .redactor-styles ul + h3,
  .redactor-styles ul + h4,
  .redactor-styles ul + h5,
  .redactor-styles ul + h6,
  .redactor-styles ol + h2,
  .redactor-styles ol + h3,
  .redactor-styles ol + h4,
  .redactor-styles ol + h5,
  .redactor-styles ol + h6,
  .redactor-styles dl + h2,
  .redactor-styles dl + h3,
  .redactor-styles dl + h4,
  .redactor-styles dl + h5,
  .redactor-styles dl + h6,
  .redactor-styles blockquote + h2,
  .redactor-styles blockquote + h3,
  .redactor-styles blockquote + h4,
  .redactor-styles blockquote + h5,
  .redactor-styles blockquote + h6,
  .redactor-styles hr + h2,
  .redactor-styles hr + h3,
  .redactor-styles hr + h4,
  .redactor-styles hr + h5,
  .redactor-styles hr + h6,
  .redactor-styles pre + h2,
  .redactor-styles pre + h3,
  .redactor-styles pre + h4,
  .redactor-styles pre + h5,
  .redactor-styles pre + h6,
  .redactor-styles table + h2,
  .redactor-styles table + h3,
  .redactor-styles table + h4,
  .redactor-styles table + h5,
  .redactor-styles table + h6,
  .redactor-styles form + h2,
  .redactor-styles form + h3,
  .redactor-styles form + h4,
  .redactor-styles form + h5,
  .redactor-styles form + h6,
  .redactor-styles figure + h2,
  .redactor-styles figure + h3,
  .redactor-styles figure + h4,
  .redactor-styles figure + h5,
  .redactor-styles figure + h6 {
    margin-top: 24px; }
  .redactor-styles ul,
  .redactor-styles ol,
  .redactor-styles ul ul,
  .redactor-styles ol ol,
  .redactor-styles ul ol,
  .redactor-styles ol ul {
    margin: 0 0 0 24px; }
  .redactor-styles ul li,
  .redactor-styles ol li {
    text-align: left; }
  .redactor-styles ol ol li {
    list-style-type: lower-alpha; }
  .redactor-styles ol ol ol li {
    list-style-type: lower-roman; }
  .redactor-styles p,
  .redactor-styles ul,
  .redactor-styles ol,
  .redactor-styles dl,
  .redactor-styles blockquote,
  .redactor-styles hr,
  .redactor-styles pre,
  .redactor-styles table,
  .redactor-styles figure,
  .redactor-styles address {
    margin-bottom: 16px; }
  .redactor-styles blockquote {
    position: relative;
    font-style: italic;
    color: rgba(0, 0, 0, 0.6); }
    .redactor-styles blockquote cite {
      font-size: 80%; }
  @media (min-width: 768px) {
    .redactor-styles blockquote {
      padding-left: 24px;
      border-left: 1px solid rgba(0, 0, 0, 0.1); } }
  .redactor-styles address {
    font-style: normal; }
  .redactor-styles dl dt {
    font-weight: bold; }
  .redactor-styles dd {
    margin-left: 24px; }
  .redactor-styles cite {
    color: rgba(0, 0, 0, 0.5);
    font-style: italic; }
  .redactor-styles s,
  .redactor-styles del {
    text-decoration: line-through; }
  .redactor-styles abbr[title],
  .redactor-styles dfn[title] {
    border-bottom: 1px dotted #000;
    cursor: help; }
  .redactor-styles strong,
  .redactor-styles b {
    font-weight: bold; }
  .redactor-styles em,
  .redactor-styles i {
    font-style: italic; }
  .redactor-styles sub,
  .redactor-styles sup {
    font-size: 10px;
    line-height: 0;
    position: relative;
    margin-left: .2rem; }
  .redactor-styles sup {
    top: -.4rem; }
  .redactor-styles sub {
    bottom: -.2rem; }
  .redactor-styles strong:empty, .redactor-styles b:empty, .redactor-styles em:empty, .redactor-styles i:empty, .redactor-styles sup:empty, .redactor-styles sub:empty, .redactor-styles u:empty, .redactor-styles ins:empty {
    display: inline-block;
    min-width: 1px;
    min-height: 1rem; }
  .redactor-styles figcaption {
    margin: 4px 0;
    font-size: 12px;
    font-style: italic;
    text-align: left; }
  .redactor-styles ins,
  .redactor-styles u {
    text-decoration: underline; }
  .redactor-styles mark {
    background-color: #ffd61e;
    color: #000;
    text-decoration: none; }
  .redactor-styles pre,
  .redactor-styles code,
  .redactor-styles kbd,
  .redactor-styles samp,
  .redactor-styles var,
  .redactor-styles output {
    font-size: 90%;
    font-style: normal;
    font-family: Consolas, Menlo, Monaco, "Courier New", monospace; }
  .redactor-styles pre {
    margin-top: 16px;
    font-size: 90%;
    line-height: 24px;
    color: rgba(0, 0, 0, 0.75);
    overflow: auto;
    background: rgba(0, 0, 0, 0.03);
    padding: 16px 20px;
    word-wrap: normal; }
  .redactor-styles mark,
  .redactor-styles code,
  .redactor-styles samp,
  .redactor-styles kbd {
    padding: 2px 4px 1px 4px;
    display: inline-block;
    line-height: 1;
    border-radius: 3px; }
  .redactor-styles code {
    background: rgba(0, 0, 0, 0.05); }
  .redactor-styles pre code {
    font-size: 100%;
    border: none;
    padding: 0;
    background: none;
    line-height: 24px; }
  .redactor-styles var {
    color: rgba(0, 0, 0, 0.5); }
  .redactor-styles samp {
    background: #46a9fc;
    color: rgba(255, 255, 255, 0.9); }
  .redactor-styles kbd {
    background: #000;
    color: rgba(255, 255, 255, 0.85);
    white-space: nowrap; }
  .redactor-styles hr {
    display: block;
    box-sizing: content-box;
    height: 1px;
    border: 0;
    border-top: 1px solid rgba(0, 0, 0, 0.1); }
  .redactor-styles img,
  .redactor-styles video,
  .redactor-styles audio,
  .redactor-styles embed,
  .redactor-styles object {
    max-width: 100%; }
  .redactor-styles img,
  .redactor-styles video,
  .redactor-styles embed,
  .redactor-styles object {
    height: auto; }
  .redactor-styles embed,
  .redactor-styles object {
    height: 100%; }
  .redactor-styles img {
    vertical-align: middle;
    -ms-interpolation-mode: bicubic; }
  .redactor-styles table {
    border-collapse: collapse;
    max-width: 100%;
    width: 100%;
    empty-cells: show; }
    .redactor-styles table caption {
      text-transform: uppercase;
      padding: 0;
      color: rgba(0, 0, 0, 0.5);
      font-size: 11px; }
    .redactor-styles table th,
    .redactor-styles table td {
      border: 1px solid #eee;
      padding: 16px;
      padding-bottom: 15px; }
    .redactor-styles table tfoot th,
    .redactor-styles table tfoot td {
      color: rgba(0, 0, 0, 0.5); }
  .redactor-styles .video-container {
    height: 0;
    padding-bottom: 56.25%;
    position: relative;
    margin-bottom: 16px; }
    .redactor-styles .video-container iframe,
    .redactor-styles .video-container object,
    .redactor-styles .video-container embed {
      position: absolute;
      top: 0;
      left: 0;
      width: 100% !important;
      height: 100% !important; }
