(function ($)
{
	$.Redactor.opts.langs['pl'] = {
    "format": "Formatuj",
    "image": "Obrazek",
    "file": "Plik",
    "link": "Link",
    "bold": "Pogrubienie",
    "italic": "Kursywa",
    "deleted": "Przekreślenie",
    "underline": "Podkreślenie",
    "bold-abbr": "B",
    "italic-abbr": "I",
    "deleted-abbr": "S",
    "underline-abbr": "U",
    "lists": "Lista",
    "link-insert": "Wstaw link",
    "link-edit": "Edytuj link",
    "link-in-new-tab": "Otwórz link w nowej karcie",
    "unlink": "Usuń link",
    "cancel": "Anuluj",
    "close": "Zamknij",
    "insert": "Wstaw",
    "save": "Zapisz",
    "delete": "Usuń",
    "text": "Text",
    "edit": "Edytuj",
    "title": "Tytuł",
    "paragraph": "Zwykły tekst",
    "quote": "Cytat",
    "code": "Kod",
    "heading1": "Nagłówek 1",
    "heading2": "Nagłówek 2",
    "heading3": "Nagłówek 3",
    "heading4": "Nagłówek 4",
    "heading5": "Nagłówek 5",
    "heading6": "Nagłówek 6",
    "filename": "Nazwa",
    "optional": "opcjonalnie",
    "unorderedlist": "Lista punktowana",
    "orderedlist": "Lista numerowana",
    "outdent": "Zmniejsz wcięcie",
    "indent": "Zwiększ wcięcie",
    "horizontalrule": "Linia pozioma",
    "upload-label": "Przenieś pliki tutaj lub... ",
    "accessibility-help-label": "Edytor tekstu",
    "caption": "Caption",
    "bulletslist": "Bullets",
    "numberslist": "Numbers",
    "image-position": "Position",
    "none": "None",
    "left": "Left",
    "right": "Right",
    "center": "Center"
};

})(jQuery);