(function ($)
{
	$.Redactor.opts.langs['hu'] = {
    "format": "Formázás",
    "image": "Kép",
    "file": "Fájl",
    "link": "Hivatkozás",
    "bold": "Félkövér",
    "italic": "Dőlt",
    "deleted": "Áthúzott",
    "underline": "Aláhúzott",
    "bold-abbr": "F",
    "italic-abbr": "D",
    "deleted-abbr": "H",
    "underline-abbr": "A",
    "lists": "Listák",
    "link-insert": "Hivatkozás beszúrása",
    "link-edit": "Hivatkozás módosítása",
    "link-in-new-tab": "Megnyitás új lapon",
    "unlink": "Hivatkozás törlése",
    "cancel": "Mégsem",
    "close": "Bezárás",
    "insert": "Beillesztés",
    "save": "Mentés",
    "delete": "Törlés",
    "text": "Szöveg",
    "edit": "Szerkesztés",
    "title": "Cím",
    "paragraph": "Normál szöveg",
    "quote": "Idézet",
    "code": "Forráskód",
    "heading1": "Címsor 1",
    "heading2": "Címsor 2",
    "heading3": "Címsor 3",
    "heading4": "Címsor 4",
    "heading5": "Címsor 5",
    "heading6": "Címsor 6",
    "filename": "Név",
    "optional": "választható",
    "unorderedlist": "Rendezett lista",
    "orderedlist": "Számozott lista",
    "outdent": "Behúzás csökkentése",
    "indent": "Behúzás növelése",
    "horizontalrule": "Vonal",
    "upload-label": "Húzza ide a fájlt vagy ",
    "accessibility-help-label": "Szövegszerkesztő",
    "caption": "Caption",
    "bulletslist": "Bullets",
    "numberslist": "Numbers",
    "image-position": "Position",
    "none": "None",
    "left": "Left",
    "right": "Right",
    "center": "Center"
};

})(jQuery);